@@ -1,11 +1,15 @@
 //! Renderer for macro invocations.
 
+use either::Either;
 use hir::HasSource;
 use ide_db::SymbolKind;
-use syntax::display::macro_label;
+use syntax::{
+    display::{fn_as_proc_macro_label, macro_label},
+    SmolStr,
+};
 
 use crate::{
-    context::CallKind,
+    context::PathKind,
     item::{CompletionItem, ImportEdit},
     render::RenderContext,
 };
@@ -23,7 +27,7 @@ pub(crate) fn render_macro(
 #[derive(Debug)]
 struct MacroRender<'a> {
     ctx: RenderContext<'a>,
-    name: String,
+    name: SmolStr,
     macro_: hir::MacroDef,
     docs: Option<hir::Documentation>,
     bra: &'static str,
@@ -32,33 +36,33 @@ struct MacroRender<'a> {
 
 impl<'a> MacroRender<'a> {
     fn new(ctx: RenderContext<'a>, name: hir::Name, macro_: hir::MacroDef) -> MacroRender<'a> {
-        let name = name.to_string();
+        let name = name.to_smol_str();
         let docs = ctx.docs(macro_);
         let docs_str = docs.as_ref().map_or("", |s| s.as_str());
-        let (bra, ket) = guess_macro_braces(&name, docs_str);
+        let (bra, ket) =
+            if macro_.is_fn_like() { guess_macro_braces(&name, docs_str) } else { ("", "") };
 
         MacroRender { ctx, name, macro_, docs, bra, ket }
     }
 
-    fn render(&self, import_to_add: Option<ImportEdit>) -> Option<CompletionItem> {
+    fn render(self, import_to_add: Option<ImportEdit>) -> Option<CompletionItem> {
         let source_range = if self.ctx.completion.is_immediately_after_macro_bang() {
             cov_mark::hit!(completes_macro_call_if_cursor_at_bang_token);
             self.ctx.completion.token.parent().map(|it| it.text_range())
         } else {
             Some(self.ctx.source_range())
         }?;
-        let mut item = CompletionItem::new(SymbolKind::Macro, source_range, &self.label());
-        item.set_documentation(self.docs.clone())
-            .set_deprecated(self.ctx.is_deprecated(self.macro_))
-            .set_detail(self.detail());
+        let mut item =
+            CompletionItem::new(SymbolKind::from(self.macro_.kind()), source_range, self.label());
+        item.set_deprecated(self.ctx.is_deprecated(self.macro_)).set_detail(self.detail());
 
         if let Some(import_to_add) = import_to_add {
             item.add_import(import_to_add);
         }
 
-        let needs_bang = !(self.ctx.completion.in_use_tree()
-            || matches!(self.ctx.completion.path_call_kind(), Some(CallKind::Mac)));
-        let has_parens = self.ctx.completion.path_call_kind().is_some();
+        let needs_bang = self.macro_.is_fn_like()
+            && !matches!(self.ctx.completion.path_kind(), Some(PathKind::Mac | PathKind::Use));
+        let has_parens = self.ctx.completion.path_is_call();
 
         match self.ctx.snippet_cap() {
             Some(cap) if needs_bang && !has_parens => {
@@ -72,35 +76,38 @@ impl<'a> MacroRender<'a> {
             }
             _ => {
                 cov_mark::hit!(dont_insert_macro_call_parens_unncessary);
-                item.insert_text(&self.name);
+                item.insert_text(&*self.name);
             }
         };
 
+        item.set_documentation(self.docs);
         Some(item.build())
     }
 
     fn needs_bang(&self) -> bool {
-        !self.ctx.completion.in_use_tree()
-            && !matches!(self.ctx.completion.path_call_kind(), Some(CallKind::Mac))
+        !matches!(self.ctx.completion.path_kind(), Some(PathKind::Mac | PathKind::Use))
     }
 
-    fn label(&self) -> String {
-        if self.needs_bang() && self.ctx.snippet_cap().is_some() {
-            format!("{}!{}…{}", self.name, self.bra, self.ket)
-        } else if self.macro_.kind() == hir::MacroKind::Derive {
-            self.name.to_string()
+    fn label(&self) -> SmolStr {
+        if !self.macro_.is_fn_like() {
+            self.name.clone()
+        } else if self.needs_bang() && self.ctx.snippet_cap().is_some() {
+            SmolStr::from_iter([&*self.name, "!", self.bra, "…", self.ket])
         } else {
             self.banged_name()
         }
     }
 
-    fn banged_name(&self) -> String {
-        format!("{}!", self.name)
+    fn banged_name(&self) -> SmolStr {
+        SmolStr::from_iter([&*self.name, "!"])
     }
 
     fn detail(&self) -> Option<String> {
-        let ast_node = self.macro_.source(self.ctx.db())?.value.left()?;
-        Some(macro_label(&ast_node))
+        let detail = match self.macro_.source(self.ctx.db())?.value {
+            Either::Left(node) => macro_label(&node),
+            Either::Right(node) => fn_as_proc_macro_label(&node),
+        };
+        Some(detail)
     }
 }
 
