@@ -122,7 +122,6 @@ fn foo() {
             bn TupleV    TupleV($1)$0
             ev TupleV
             ct CONST
-            ma makro!(…) #[macro_export] macro_rules! makro
         "##]],
     );
 }
@@ -131,19 +130,24 @@ fn foo() {
 fn irrefutable() {
     check(
         r#"
+enum SingleVariantEnum {
+    Variant
+}
+use SingleVariantEnum::Variant;
 fn foo() {
    let a$0
 }
 "#,
         expect![[r##"
             kw mut
-            bn Record    Record { field$1 }$0
+            bn Record            Record { field$1 }$0
             st Record
-            bn Tuple     Tuple($1)$0
+            bn Tuple             Tuple($1)$0
             st Tuple
+            ev Variant
+            en SingleVariantEnum
             st Unit
-            ma makro!(…) #[macro_export] macro_rules! makro
-            ma makro!(…) #[macro_export] macro_rules! makro
+            ma makro!(…)         #[macro_export] macro_rules! makro
         "##]],
     );
 }
@@ -163,6 +167,20 @@ fn foo(a$0) {
             st Tuple
             st Unit
             ma makro!(…) #[macro_export] macro_rules! makro
+        "##]],
+    );
+    check(
+        r#"
+fn foo(a$0: Tuple) {
+}
+"#,
+        expect![[r##"
+            kw mut
+            bn Record    Record { field$1 }$0
+            st Record
+            bn Tuple     Tuple($1)$0
+            st Tuple
+            st Unit
             ma makro!(…) #[macro_export] macro_rules! makro
         "##]],
     );
@@ -274,11 +292,11 @@ fn func() {
 "#,
         expect![[r#"
             ev TupleV(…)   (u32)
-            ev RecordV     { field: u32 }
+            ev RecordV     {field: u32}
             ev UnitV       ()
-            ct ASSOC_CONST const ASSOC_CONST: () = ();
+            ct ASSOC_CONST const ASSOC_CONST: ();
             fn assoc_fn()  fn()
-            ta AssocType   type AssocType = ();
+            ta AssocType   type AssocType;
         "#]],
     );
 }
@@ -312,3 +330,41 @@ fn outer(Foo { bar$0 }: Foo) {}
         expect![[r#""#]],
     )
 }
+
+#[test]
+fn completes_in_fn_param() {
+    check_empty(
+        r#"
+struct Foo { bar: Bar }
+struct Bar(u32);
+fn foo($0) {}
+"#,
+        expect![[r#"
+            kw mut
+            bn Foo Foo { bar$1 }: Foo$0
+            st Foo
+            bn Bar Bar($1): Bar$0
+            st Bar
+        "#]],
+    )
+}
+
+#[test]
+fn completes_in_closure_param() {
+    check_empty(
+        r#"
+struct Foo { bar: Bar }
+struct Bar(u32);
+fn foo() {
+    |$0| {};
+}
+"#,
+        expect![[r#"
+            kw mut
+            bn Foo Foo { bar$1 }$0
+            st Foo
+            bn Bar Bar($1)$0
+            st Bar
+        "#]],
+    )
+}
